Includes traffic flow data acquired from a network of Automatic Number Plate Recognition (ANPR) cameras and computed via the anprx python package. Using the anprflows R package, a spatio-temporal window is used to capture relevant traffic and spatial data around the epicentre of the traffic event.
1 |
A list of events, each containing the following data:
nodesids of locations potentially affected by the incident
flows_ltibble containing the number of vehicles passing through each of the locations during each time period
flows_odtibble containing the number, speed statistics and other information of vehicles passing between each pair of locations during each time period
spatialspatial data composed of several sf dataframes, cropped to the area of interest. Includes data about monitored locations, shortest paths between locations, the enclosing arterial and primary road networks and nearby amenities
networkasymptotic flow network computed over the chosen spatio-temporal window
hparamsvalues of the hyperparameters used to identify spurious flows and crop spatial features
incidentapproximate point where incident or congestion was reported by traffic authorities
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.