Data describing several hand-picked events that affected traffic flow in the region of Tyne and Wear in the year 2018:
1 |
A tibble containing the following columns:
idevent id
dateevent date
start_datetimetraffic flow temporal window start time
end_datetimetraffic flow temporal window end time
event_timewhen the event was reported on twitter
tweettweet content
linkurl link to the original tweet
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.